==> react-toolbox-0.10.20.tgz: package/spec/components/drawer.jsx <==
import React from 'react';
import Button from '../../components/button';
import Drawer from '../../components/drawer';

export default React.createClass({
  displayName: 'DrawerTest',

  onClick (ref, method) {
    this.refs[ref][method]();
  },

  render () {
    return (
      <section>
        <h5>Drawer</h5>
        <p>You can navigate using a drawer to the left or right. They can be auto-closable or not.</p>

        <Drawer ref='left' hideable={true}>
          <h5>Officia deserunt mollit.</h5>
          <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
          <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
        </Drawer>

        <Drawer ref='right' type='right'>
          <Button label='Close' onClick={this.onClick.bind(null, 'right', 'hide')} />
        </Drawer>

        <nav>
          <Button className='accent' label='Drawer left hideable' type='raised' onClick={this.onClick.bind(null, 'left', 'show')} />
          <Button className='primary' label='Drawer right' type='raised' onClick={this.onClick.bind(null, 'right', 'show')} />
        </nav>
      </section>
    );
  }
});

==> react-toolbox-0.12.2.tgz: package/spec/components/drawer.jsx <==
import React from 'react';
import Button from '../../components/button';
import Drawer from '../../components/drawer';

class DrawerTest extends React.Component {
  state = {
    leftActive: false,
    rightActive: false
  };

  handleToggleLeft = () => {
    this.setState({leftActive: !this.state.leftActive});
  };

  handleToggleRight = () => {
    this.setState({rightActive: !this.state.rightActive});
  }

  render () {
    return (
      <section>
        <h5>Drawer</h5>
        <p>You can navigate using a drawer to the left or right.</p>

        <Drawer active={this.state.leftActive} onOverlayClick={this.handleToggleLeft}>
          <h5>Officia deserunt mollit.</h5>
          <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
          <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
        </Drawer>

        <Drawer active={this.state.rightActive} type='right'>
          <Button label='Close' onClick={this.handleToggleRight} />
        </Drawer>

        <nav>
          <Button accent label='Drawer left' kind='raised' onClick={this.handleToggleLeft} />
          <Button primary label='Drawer right' kind='raised' onClick={this.handleToggleRight} />
        </nav>
      </section>
    );
  }
}

export default DrawerTest;
